<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="设备" prop="deviceId">
        <el-select v-model="queryParams.deviceId" placeholder="请选择设备" filterable>
          <el-option
            v-for="dict in devices"
            :key="dict.deviceId"
            :label="dict.deviceName"
            :value="dict.deviceId"
          ></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="设备阈值" prop="deviceThreshold">
        <el-input
          v-model="queryParams.deviceThreshold"
          placeholder="请输入设备阈值"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="关联管道" prop="relationPipeId">
        <el-select v-model="queryParams.relationPipeId" placeholder="请选择关联管道" filterable>
          <el-option
            v-for="dict in pipes"
            :key="dict.pipeId"
            :label="dict.pipeName"
            :value="dict.pipeId"
          ></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="关联管道阈值" prop="relationPipeThreshold">
        <el-input
          v-model="queryParams.relationPipeThreshold"
          placeholder="请输入关联管道阈值"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="关联设备" prop="relationDeviceId">
        <el-select v-model="queryParams.relationDeviceId" placeholder="请选择关联设备" filterable>
          <el-option
            v-for="dict in devices"
            :key="dict.deviceId"
            :label="dict.deviceName"
            :value="dict.deviceId"
          ></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="关联设备阈值" prop="relationDeviceThreshold">
        <el-input
          v-model="queryParams.relationDeviceThreshold"
          placeholder="请输入关联设备阈值"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:device:add']"
        >新增</el-button>
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="dialogVisible = true"
        >批量新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:device:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:device:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
		  :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['system:device:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="deviceList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="设备监控id" align="center" prop="monitorId" />
      <el-table-column label="设备" align="center" prop="deviceName" />
      <el-table-column label="设备阈值" align="center" prop="deviceThreshold" />
      <el-table-column label="关联管道" align="center" prop="relationPipeName" />
      <el-table-column label="关联管道阈值" align="center" prop="relationPipeThreshold" />
      <el-table-column label="关联设备" align="center" prop="relationDeviceName" />
      <el-table-column label="关联设备阈值" align="center" prop="relationDeviceThreshold" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:device:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:device:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改设备监控对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="设备id" prop="deviceId">
          <!--<el-input v-model="form.deviceId" placeholder="请输入设备id" />-->
          <el-select v-model="form.deviceId" placeholder="请选择设备" filterable>
            <el-option
              v-for="dict in devices"
              :key="dict.deviceId"
              :label="dict.deviceName"
              :value="dict.deviceId"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="设备阈值" prop="deviceThreshold">
          <el-input v-model="form.deviceThreshold" placeholder="请输入设备阈值" />
        </el-form-item>
        <el-form-item label="关联管道id" prop="relationPipeId">
          <!--<el-input v-model="form.relationPipeId" placeholder="请输入关联管道id" />-->
          <el-select v-model="form.relationPipeId" placeholder="请选择关联管道" filterable>
            <el-option
              v-for="dict in pipes"
              :key="dict.pipeId"
              :label="dict.pipeName"
              :value="dict.pipeId"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="关联管道阈值" prop="relationPipeThreshold">
          <el-input v-model="form.relationPipeThreshold" placeholder="请输入关联管道阈值" />
        </el-form-item>
        <el-form-item label="关联设备id" prop="relationDeviceId">
         <!-- <el-input v-model="form.relationDeviceId" placeholder="请输入关联设备id" />-->
          <el-select v-model="form.relationDeviceId" placeholder="请选择关联设备" filterable>
            <el-option
              v-for="dict in devices"
              :key="dict.deviceId"
              :label="dict.deviceName"
              :value="dict.deviceId"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="关联设备阈值" prop="relationDeviceThreshold">
          <el-input v-model="form.relationDeviceThreshold" placeholder="请输入关联设备阈值" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <!--批量新增-->
    <el-dialog title="批量新增" :visible.sync="dialogVisible" append-to-body>
      <div class="add-div" style="width: 100%;height: 100%;padding: 50px;">
        <el-row :gutter="50">
          <span>新增设备</span>
          <!--<el-input placeholder="请输入设备名称" style="width: 260px;margin-left: 20px;"></el-input>-->
          <el-select v-model="subForm.deviceId" placeholder="请选择设备名称" filterable>
            <el-option
              v-for="dict in devices"
              :key="dict.deviceId"
              :label="dict.deviceName"
              :value="dict.deviceId"
            ></el-option>
          </el-select>
          <el-input v-model="subForm.deviceThreshold" placeholder="请输入设备阈值" style="width: 260px;margin-left: 50px;"></el-input>
        </el-row>
        <el-button type="primary" class="el-icon-plus clolos1" @click="addPdfFile" style="margin-top: 20px;margin-bottom: 20px;">新增关联设备</el-button>
        <div class="add_pdf" v-for="(item, index) in subForm.relationDevices" :key="index" style="margin-bottom: 30px;">

          <el-form :model="item" label-width="80px">
            <el-row :gutter="50">
              <el-col :span="20" style="float: left;box-shadow: rgb(233, 229, 229) 3px 3px 7px 2px;padding-top: 20px;padding-left: 15px;">
                <el-form-item label="关联管道:" prop="pipeCode">
                  <!--<el-input v-model="item.sss" placeholder="请输入关联管道名称" style="width: 40%;margin-left: 20px;"></el-input>-->
                  <el-select v-model="item.relationPipeId" placeholder="请选择关联管道名称" filterable>
                    <el-option
                      v-for="dict in pipes"
                      :key="dict.pipeId"
                      :label="dict.pipeName"
                      :value="dict.pipeId"
                    ></el-option>
                  </el-select>
                  <el-input v-model="item.relationPipeThreshold" placeholder="请输入关联管道阈值" style="width: 40%;margin-left: 50px;"></el-input>
                </el-form-item>
                <el-form-item label="关联设备:" prop="pipeCode">
                 <!-- <el-input v-model="item.qqq" placeholder="请输入关联设备名称" style="width: 40%;margin-left: 20px;"></el-input>-->
                  <el-select v-model="item.relationDeviceId" placeholder="请选择关联设备名称" filterable>
                    <el-option
                      v-for="dict in devices"
                      :key="dict.deviceId"
                      :label="dict.deviceName"
                      :value="dict.deviceId"
                    ></el-option>
                  </el-select>
                  <el-input v-model="item.relationDeviceThreshold" placeholder="请输入关联设备阈值" style="width: 40%;margin-left: 50px;"></el-input>
                </el-form-item>
              </el-col>
              <div style="float: left;margin-top: 50px;margin-left: 50px;">
                <el-button type="danger" class="el-icon-delete clolos clolos3" @click="deletePdf(index)" circle></el-button>
              </div>
            </el-row>
          </el-form>
          <!-- <div v-show="index !== 0"> -->
        </div>
        <el-form label-width="100px">
          <el-form-item style="margin-left:100px;margin-top:40px;">
            <el-button type="primary" @click="batchSubmit()">提交</el-button>
            <el-button @click="dialogVisible = false">返回</el-button>
          </el-form-item>
        </el-form>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listDevice, getDevice, delDevice, addDevice, updateDevice, exportDevice, batchAdd } from "@/api/device/deviceMonitor";
import { getAllDeviceInfo } from "@/api/device/deviceInfo";
import { pipeAllInfoList } from "@/api/device/pipe";
export default {
  name: "Device",
  components: {
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 设备监控表格数据
      deviceList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deviceId: null,
        deviceThreshold: null,
        relationPipeId: null,
        relationPipeThreshold: null,
        relationDeviceId: null,
        relationDeviceThreshold: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      },
      devices: [],
      pipes: [],
      dialogVisible: false,
      subForm:{
        relationDevices: [{}]
      }
    };
  },
  created() {
    this.getList();
    this.getAllDeviceInfo();
    this.pipeAllInfoList();
  },
  methods: {
    /** 查询设备监控列表 */
    getList() {
      this.loading = true;
      listDevice(this.queryParams).then(response => {
        this.deviceList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        monitorId: null,
        deviceId: null,
        deviceThreshold: null,
        relationPipeId: null,
        relationPipeThreshold: null,
        relationDeviceId: null,
        relationDeviceThreshold: null,
        createTime: null,
        updateTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.monitorId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加设备监控";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const monitorId = row.monitorId || this.ids
      getDevice(monitorId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改设备监控";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.monitorId != null) {
            updateDevice(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDevice(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const monitorIds = row.monitorId || this.ids;
      this.$confirm('是否确认删除设备监控编号为"' + monitorIds + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delDevice(monitorIds);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有设备监控数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportDevice(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    },
    getAllDeviceInfo(){
      getAllDeviceInfo().then(response => {
        this.devices = response.data;
      });
    },
    pipeAllInfoList(){
      pipeAllInfoList().then(res =>{
        this.pipes = res.data;
      });
    },
    addPdfFile(){
      this.subForm.relationDevices.push({});
    },
    deletePdf(index){
      this.subForm.relationDevices.splice(index,1);
      console.log(this.subForm,"fdfdfdfasdfdsf");
    },
    batchSubmit(){
      batchAdd(this.subForm).then(res =>{
        this.msgSuccess("新增成功");
        this.dialogVisible = false;
        this.getList();
      });

    }
  }
};
</script>
